Modules
Functions
- build
- Call from
build.rs. Currently, the structnamemust appear at the top level ofrust_file. Include anyverilog_filesrequired to build the module specified in theferrilateattribute applied toname. All file paths are relative to the crate root.